@@ -1,5 +1,4 @@
 import requests
-import json
 from datetime import datetime
 from cad_tickers.exchanges.tsx.gql_data import GQL
 from typing import Union
@@ -32,14 +31,7 @@ def get_ticker_filings(
             "locale": "en",
         },
     )
-    try:
-        allData = r.json()
-    except json.decoder.JSONDecodeError as error:
-        print(error)
-        print(f"Failed to decode docs for {symbol}")
-        print(r)
-        return None
-    # Check for errors
+    allData = r.json()
     try:
         data = allData["data"]
         return data
